@@ -1,8 +1,6 @@
 """Python port of Lo-Dash
 """
 
-from __future__ import absolute_import
-
 from .__meta__ import (
     __title__,
     __summary__,
@@ -18,28 +16,44 @@ from .__meta__ import (
 # Arrays
 #
 
-from .api.arrays import (
+from .arrays import (
+    cat,
+    chunk,
     compact,
     difference,
     drop,
+    drop_right,
+    drop_right_while,
+    drop_while,
     find_index,
     find_last_index,
     first,
     flatten,
+    flatten_deep,
     head,
     index_of,
     initial,
+    intercalate,
+    interleave,
     intersection,
+    intersperse,
     last,
     last_index_of,
+    mapcat,
     object_,
     pull,
-    range_,
+    pull_at,
     remove,
     rest,
+    slice_,
     sorted_index,
+    sorted_last_index,
+    split_at,
     tail,
     take,
+    take_right,
+    take_right_while,
+    take_while,
     union,
     uniq,
     unique,
@@ -55,9 +69,11 @@ from .api.arrays import (
 # Chaining
 #
 
-from .api.chaining import (
+from .chaining import (
     chain,
     tap,
+    thru,
+    _Underscore
 )
 
 
@@ -65,7 +81,7 @@ from .api.chaining import (
 # Collections
 #
 
-from .api.collections import (
+from .collections import (
     all_,
     any_,
     at,
@@ -92,9 +108,12 @@ from .api.collections import (
     map_,
     max_,
     min_,
+    partition,
     pluck,
     reduce_,
     reduce_right,
+    reductions,
+    reductions_right,
     reject,
     sample,
     select,
@@ -111,12 +130,21 @@ from .api.collections import (
 # Functions
 #
 
-from .api.functions import (
+from .functions import (
     after,
+    before,
     compose,
+    conjoin,
     curry,
+    curry_right,
     debounce,
     delay,
+    disjoin,
+    flow,
+    flow_right,
+    iterated,
+    juxtapose,
+    negate,
     once,
     partial,
     partial_right,
@@ -129,8 +157,9 @@ from .api.functions import (
 # Objects
 #
 
-from .api.objects import (
+from .objects import (
     assign,
+    callables,
     clone,
     clone_deep,
     defaults,
@@ -141,22 +170,12 @@ from .api.objects import (
     for_in_right,
     for_own,
     for_own_right,
-    functions,
+    get_path,
     has,
+    has_path,
     invert,
-    is_boolean,
-    is_date,
-    is_empty,
-    is_equal,
-    is_function,
-    is_list,
-    is_nan,
-    is_none,
-    is_number,
-    is_object,
-    is_plain_object,
-    is_string,
     keys,
+    keys_in,
     map_values,
     merge,
     methods,
@@ -164,20 +183,95 @@ from .api.objects import (
     pairs,
     parse_int,
     pick,
+    rename_keys,
+    set_path,
+    to_string,
     transform,
+    update_path,
     values,
+    values_in,
 )
 
 
+#
+# Predicates
+#
+
+from .predicates import (
+    is_associative,
+    is_boolean,
+    is_date,
+    is_decreasing,
+    is_empty,
+    is_equal,
+    is_error,
+    is_even,
+    is_float,
+    is_function,
+    is_increasing,
+    is_indexed,
+    is_instance_of,
+    is_integer,
+    is_json,
+    is_list,
+    is_monotone,
+    is_nan,
+    is_negative,
+    is_none,
+    is_number,
+    is_object,
+    is_odd,
+    is_plain_object,
+    is_positive,
+    is_re,
+    is_reg_exp,
+    is_strictly_decreasing,
+    is_strictly_increasing,
+    is_string,
+    is_zero,
+)
+
+
+#
+# Strings
+#
+
+from .strings import (
+    camel_case,
+    capitalize,
+    deburr,
+    ends_with,
+    escape,
+    escape_reg_exp,
+    escape_re,
+    explode,
+    implode,
+    js_match,
+    js_replace,
+    kebab_case,
+    pad,
+    pad_left,
+    pad_right,
+    repeat,
+    snake_case,
+    starts_with,
+    trim,
+    trim_left,
+    trim_right,
+    trunc,
+    unescape,
+    words,
+)
+
 #
 # Utilities
 #
 
-from .api.utilities import (
+from .utilities import (
+    attempt,
     callback,
     constant,
-    create_callback,
-    escape,
+    iteratee,
     identity,
     matches,
     memoize,
@@ -186,9 +280,9 @@ from .api.utilities import (
     prop,
     property_,
     random,
+    range_,
     result,
     times,
-    unescape,
     unique_id,
 )
 
@@ -196,6 +290,14 @@ from .api.utilities import (
 #
 # Exceptions
 #
-from .api.exceptions import (
+
+from .exceptions import (
     InvalidMethod
 )
+
+
+#
+# "_" Instance
+#
+
+_ = _Underscore()
