@@ -12,10 +12,11 @@ __all__ = [
 ]
 
 __title__ = 'pydash'
-__summary__ = 'Python port of Lo-Dash'
+__summary__ = ('A utility library for doing "stuff" in a functional way. '
+               'Based on the Lo-Dash Javascript library.')
 __url__ = 'https://github.com/dgilland/pydash'
 
-__version__ = '1.0.0'
+__version__ = '2.0.0'
 
 __author__ = 'Derrick Gilland'
 __email__ = 'dgilland@gmail.com'
