@@ -16,6 +16,8 @@ from functools import partial
 
 
 PY3 = sys.version_info[0] == 3
+PY26 = sys.version_info[0:2] == (2, 6)
+
 _identity = lambda x: x
 
 
@@ -33,8 +35,10 @@ if PY3:
     _range = range
 
     implements_to_string = _identity
+    izip = zip
 else:
     from HTMLParser import HTMLParser
+    from itertools import izip
     text_type = unicode
     string_types = (str, unicode)
     integer_types = (int, long)
